@@ -14,7 +14,7 @@ import numpy as np
 from sklearn.utils import check_array
 
 from ...logging import Logger
-from ...preprocessing import split_data_scenarios
+from ...binning.preprocessing import split_data_scenarios
 from ..binning import OptimalBinning
 from ..binning_statistics import bin_info
 from ..binning_statistics import BinningTable
@@ -353,7 +353,7 @@ class SBOptimalBinning(OptimalBinning):
 
         Returns
         -------
-        self : object
+        self : SBOptimalBinning
             Fitted optimal binning.
         """
         return self._fit(X, Y, weights, check_input)
