@@ -24,13 +24,10 @@ from .rounding import RoundingMIP
 from .scorecard_information import print_scorecard_information
 
 
-def _check_parameters(target, binning_process, estimator, scaling_method,
+def _check_parameters(binning_process, estimator, scaling_method,
                       scaling_method_params, intercept_based,
                       reverse_scorecard, rounding, verbose):
 
-    if not isinstance(target, str):
-        raise TypeError("target must be a string.")
-
     if not isinstance(binning_process, BinningProcess):
         raise TypeError("binning_process must be a BinningProcess instance.")
 
@@ -164,9 +161,6 @@ class Scorecard(Base, BaseEstimator):
 
     Parameters
     ----------
-    target : str
-        Target column.
-
     binning_process : object
         A ``BinningProcess`` instance.
 
@@ -217,11 +211,10 @@ class Scorecard(Base, BaseEstimator):
     intercept_ : float
         The intercept if ``intercept_based=True``.
     """
-    def __init__(self, target, binning_process, estimator, scaling_method=None,
+    def __init__(self, binning_process, estimator, scaling_method=None,
                  scaling_method_params=None, intercept_based=False,
                  reverse_scorecard=False, rounding=False, verbose=False):
 
-        self.target = target
         self.binning_process = binning_process
         self.estimator = estimator
         self.scaling_method = scaling_method
@@ -255,15 +248,23 @@ class Scorecard(Base, BaseEstimator):
 
         self._is_fitted = False
 
-    def fit(self, df, metric_special=0, metric_missing=0, show_digits=2,
-            check_input=False):
+    def fit(self, X, y, sample_weight=None, metric_special=0, metric_missing=0,
+            show_digits=2, check_input=False):
         """Fit scorecard.
 
         Parameters
         ----------
-        df : pandas.DataFrame (n_samples, n_features)
+        X : pandas.DataFrame (n_samples, n_features)
             Training vector, where n_samples is the number of samples.
 
+        y : array-like of shape (n_samples,)
+            Target vector relative to x.
+
+        sample_weight : array-like of shape (n_samples,) (default=None)
+            Array of weights that are assigned to individual samples.
+            If not provided, then each sample is given unit weight.
+            This option is only available for a binary target.
+
         metric_special : float or str (default=0)
             The metric value to transform special codes in the input vector.
             Supported metrics are "empirical" to use the empirical WoE or
@@ -282,11 +283,11 @@ class Scorecard(Base, BaseEstimator):
 
         Returns
         -------
-        self : object
+        self : Scorecard
             Fitted scorecard.
         """
-        return self._fit(df, metric_special, metric_missing, show_digits,
-                         check_input)
+        return self._fit(X, y, sample_weight, metric_special, metric_missing,
+                         show_digits, check_input)
 
     def information(self, print_level=1):
         """Print overview information about the options settings and
@@ -317,35 +318,35 @@ class Scorecard(Base, BaseEstimator):
             self._time_binning_process, self._time_estimator,
             self._time_build_scorecard, self._time_rounding, dict_user_options)
 
-    def predict(self, df):
+    def predict(self, X):
         """Predict using the fitted underlying estimator and the reduced
         dataset.
 
         Parameters
         ----------
-        df : pandas.DataFrame (n_samples, n_features)
+        X : pandas.DataFrame (n_samples, n_features)
             Training vector, where n_samples is the number of samples.
 
         Returns
         -------
-        y: array of shape (n_samples)
+        pred: array of shape (n_samples)
             The predicted target values.
         """
         self._check_is_fitted()
 
-        df_t = df[self.binning_process_.variable_names]
-        df_t = self.binning_process_.transform(
-            df_t, metric_special=self._metric_special,
+        X_t = X[self.binning_process_.variable_names]
+        X_t = self.binning_process_.transform(
+            X, metric_special=self._metric_special,
             metric_missing=self._metric_missing)
-        return self.estimator_.predict(df_t)
+        return self.estimator_.predict(X_t)
 
-    def predict_proba(self, df):
+    def predict_proba(self, X):
         """Predict class probabilities using the fitted underlying estimator
         and the reduced dataset.
 
         Parameters
         ----------
-        df : pandas.DataFrame (n_samples, n_features)
+        X : pandas.DataFrame (n_samples, n_features)
             Training vector, where n_samples is the number of samples.
 
         Returns
@@ -355,18 +356,18 @@ class Scorecard(Base, BaseEstimator):
         """
         self._check_is_fitted()
 
-        df_t = df[self.binning_process_.variable_names]
-        df_t = self.binning_process_.transform(
-            df_t, metric_special=self._metric_special,
+        X_t = X[self.binning_process_.variable_names]
+        X_t = self.binning_process_.transform(
+            X, metric_special=self._metric_special,
             metric_missing=self._metric_missing)
-        return self.estimator_.predict_proba(df_t)
+        return self.estimator_.predict_proba(X_t)
 
-    def score(self, df):
+    def score(self, X):
         """Score of the dataset.
 
         Parameters
         ----------
-        df : pandas.DataFrame (n_samples, n_features)
+        X : pandas.DataFrame (n_samples, n_features)
             Training vector, where n_samples is the number of samples.
 
         Returns
@@ -376,16 +377,16 @@ class Scorecard(Base, BaseEstimator):
         """
         self._check_is_fitted()
 
-        df_t = df[self.binning_process_.variable_names]
-        df_t = self.binning_process_.transform(df_t, metric="indices")
+        X_t = X[self.binning_process_.variable_names]
+        X_t = self.binning_process_.transform(X_t, metric="indices")
 
-        score_ = np.zeros(df_t.shape[0])
+        score_ = np.zeros(X_t.shape[0])
         selected_variables = self.binning_process_.get_support(names=True)
 
         for variable in selected_variables:
             mask = self._df_scorecard.Variable == variable
             points = self._df_scorecard[mask].Points.values
-            score_ += points[df_t[variable]]
+            score_ += points[X_t[variable]]
 
         return score_ + self.intercept_
 
@@ -455,8 +456,8 @@ class Scorecard(Base, BaseEstimator):
         with open(path, "wb") as f:
             dill.dump(self, f)
 
-    def _fit(self, df, metric_special, metric_missing, show_digits,
-             check_input):
+    def _fit(self, X, y, sample_weight, metric_special, metric_missing,
+             show_digits, check_input):
 
         # Store the metrics for missing and special bins for predictions
         self._metric_special = metric_special
@@ -470,9 +471,12 @@ class Scorecard(Base, BaseEstimator):
 
         _check_parameters(**self.get_params(deep=False))
 
+        # Check X dtype
+        if not isinstance(X, pd.DataFrame):
+            raise TypeError("X must be a pandas.DataFrame.")
+
         # Target type and metric
-        target = df[self.target]
-        self._target_dtype = type_of_target(target)
+        self._target_dtype = type_of_target(y)
 
         if self._target_dtype not in ("binary", "continuous"):
             raise ValueError("Target type {} is not supported."
@@ -482,6 +486,11 @@ class Scorecard(Base, BaseEstimator):
                                  self.scaling_method_params,
                                  self._target_dtype)
 
+        # Check sample weight
+        if sample_weight is not None and self._target_dtype != "binary":
+            raise ValueError("Target type {} does not support sample weight."
+                             .format(self._target_dtype))
+
         if self._target_dtype == "binary":
             metric = "woe"
             bt_metric = "WoE"
@@ -501,10 +510,9 @@ class Scorecard(Base, BaseEstimator):
         # Suppress binning process verbosity
         self.binning_process_.set_params(verbose=False)
 
-        df_t = self.binning_process_.fit_transform(
-            df[self.binning_process.variable_names], target,
-            metric, metric_special, metric_missing, show_digits,
-            check_input)
+        X_t = self.binning_process_.fit_transform(
+            X[self.binning_process.variable_names], y, sample_weight, metric,
+            metric_special, metric_missing, show_digits, check_input)
 
         self._time_binning_process = time.perf_counter() - time_binning_process
 
@@ -518,7 +526,7 @@ class Scorecard(Base, BaseEstimator):
             self._logger.info("Fitting estimator.")
 
         self.estimator_ = clone(self.estimator)
-        self.estimator_.fit(df_t, target)
+        self.estimator_.fit(X_t, y, sample_weight)
 
         self._time_estimator = time.perf_counter() - time_estimator
 
